<?php
/*******************************************************************************
 *   Functions for editors
 *******************************************************************************
 *   GuppY PHP Script - version 5.0
 *   CeCILL Copyright (C) 2004-2014 by Laurent Duveau
 *   Initiated by Laurent Duveau and Nicolas Alves
 *   Web site = http://www.freeguppy.org/
 *   e-mail   = guppy@freeguppy.org
 *   V5 developed by Lud Bienaimé
 *      with the participation of Jean-Michel Misrachi and the GuppY Team
 *******************************************************************************
 *   Latest Changes :
 * v5.02.00 (May 09, 2017)       : suppress flash management
 ******************************************************************************/

if (stristr($_SERVER["SCRIPT_NAME"], "editors_functions.php")) {
	header("location:../index.php");
	die();
}

/**
 * Affiche l'éditeur dans la partie administration 
 * 
 * @param string  $name    Nom de l'éditeur
 * @param string  $width   Largeur de l'éditeur (voir fichier de condif)
 * @param string  $height  Hauteur de l'éditeur
 * @param string  $content Contenu de l'éditeur
 * @param boolean $wysiwyg Editeur wysiwyg (true) ou non (false)
 * @param array   $params  Paramètres optionnels
 * @return string
 */
function display_editor($name, $width, $height, $content, $wysiwyg = TRUE, $params = array())
{
    $path_editors = 'inc/';
    
    if ($wysiwyg) {
        WYSIWYG_editor($name, $width, $height, $content, $params, $path_editors);
    } else {
        //TEXTAREA_editor($name, $width, $height, $content, $params, $path_editors);   
    }
}

// --------------------------------------------------------------------

/**
 * Affiche un éditeur WYSIWYG 
 * 
 * @param string $name Nom de l'éditeur
 * @param string $width Largeur de l'éditeur (voir fichier de condif)
 * @param string $height Hauteur de l'éditeur
 * @param string $value Contenu de l'éditeur
 * @param 
 * @return string
 */
function WYSIWYG_editor($name, $width, $height, $value, $params = array(), $path_editors = '')
{
    settype($params, 'array');
    
    /**
     * Editeur CKEditor
     */
    if (is_file(CHEMIN.'inc/ckeditor/ckeditor.php'))
    {
        require_once CHEMIN.'inc/ckeditor/ckeditor.php';
        
        $path = 'inc/ckeditor/';
        $toolbarName = empty($params['toolbarName'])? 'Guppy_out_min' : $params['toolbarName'];
     
        return CKeditor($name, $path, $width, $height, $value, $toolbarName, $path_editors);
    }
    //
    
    return FALSE;   
}

// --------------------------------------------------------------------

/**
 * Affiche un éditeur NON WYSIWYG 
 * 
 * @param string $name Nom de l'éditeur
 * @param string $width Largeur de l'éditeur (voir fichier de condif)
 * @param string $height Hauteur de l'éditeur
 * @param string $value Contenu de l'éditeur
 * @return string
 */
function TEXTAREA_editor($name, $width, $height, $value, $params = array(), $path_editors = '')
{    
    
    return FALSE;   
}

// --------------------------------------------------------------------

/**
 * Affiche l'éditeur WYSIWYG CKEditor
 * 
 * @param string $name Nom de l'éditeur
 * @param string $path Chemin relatif du répertoire contenant l'éditeur
 * @param string $width Largeur de l'éditeur (voir fichier de condif)
 * @param string $height Hauteur de l'éditeur
 * @param string $value Contenu de l'éditeur
 * @param string $toolbarname Nom de la barre d'outil de l'éditeur
 * @param string $pathDirMinieditor Chemin relatif du répertoire contenant la configuration de l'éditeur
 * @return string
 */
function CKeditor($name, $path, $width, $height, $value, $toolbarname, $pathDirMinieditor)
{
	global $site, $lng;
    
    $site[37] = empty($site[37]) ? 'moonocolor_v1.1' : $site[37];
    
	/**
     * Création de l'éditeur
     */
	$oCKeditor = new CKeditor() ;
	$oCKeditor -> basePath = $site[3].$path;
    $oCKeditor -> config['width'] = (strpos($_SERVER['HTTP_USER_AGENT'], "WebKit") !== false)? '577px' : $width;   // Correction bug avec Safari et Chrome
    // $oCKeditor -> config['width'] = $width;
	$oCKeditor -> config['height'] = $height;
	$oCKeditor -> config['baseHref'] = $site[3];
	$oCKeditor -> config['customConfig'] = $site[3].'inc/ckeditor_config/guppy_ckconfig.js';
	$oCKeditor -> config['contentsCss'] = $site[3].'inc/ckeditor_config/guppy_contents.css';
	$oCKeditor -> config['language'] = is_file(CHEMIN.'inc/ckeditor/lang/'.$lng.'.js') ? $lng : 'en';	
	$oCKeditor -> config['toolbar'] = $toolbarname;
	$oCKeditor -> config['smiley_path'] = $site[3].'inc/ckeditor/plugins/smiley/images/';
   	$oCKeditor -> config['skin'] = $site[37].', '.$site[3].'inc/ckeditor_config/skins/'.$site[37].'/';
    //
    
    // Affichage de l'éditeur
    echo '<div class="textCenter">'.$oCKeditor -> editor($name, $value).'</div>';
	//
    
	// Affichage de la barre de smileys pour l'éditeur
    echo get_toolbar_guppy_smileys($name);    
}

// --------------------------------------------------------------------


/**
 * Défini le chemin du répertoire contenant les smileys de guppy
 */
define('PATH_GUPPYSMILEY', 'inc/img/smileys/');	

// --------------------------------------------------------------------

/**
 * Retourne la barre de smileys de guppy pour être intégrer dans l'éditeur
 * 
 * @param string Nom de l'éditeur
 * @return string
 */
function get_toolbar_guppy_smileys($name)
{
	$smileyGuppy = array('cool', 'wink', 'biggrin', 'smile', 'frown', 'eek', 'mad', 'confused', 'rolleyes', 'tongue', 'cry');
	
    $html = '<div class="guppy_smileys" style="text-align:center; margin-top:10px;">';
    
	for ($i = 0; $i < count($smileyGuppy); $i++) {
		$smileyPath = CHEMIN.PATH_GUPPYSMILEY.$smileyGuppy[$i].'.gif';
		if (is_file($smileyPath)) { 
			$imgSize = getimagesize($smileyPath);
			$html .= '<img class="icon" style="cursor:pointer;" src="'.$smileyPath.'" '.$imgSize[3].' alt="'.$smileyGuppy[$i].'" title="'.$smileyGuppy[$i].'" onclick="insert_smiley_in_editor(\''.$name.'\', \''.PATH_GUPPYSMILEY.$smileyGuppy[$i].'.gif\', \''.$smileyGuppy[$i].'\', \''.$imgSize[0].'\', \''.$imgSize[1].'\');" onmouseover="this.className=\'icon_hover\'" onmouseout="this.className=\'icon_out\'" />'."\n";
		}
	}
    
    $html .= '</div>';
    
	return $html;
}

// --------------------------------------------------------------------

/**
 * Insère les fonctions javascripts nécessaires pour les éditeurs
 */ 
$headinc .= '<script type="text/javascript" src="'.CHEMIN.'inc/ckeditor_config/editors_scripts.js"></script>';

// --------------------------------------------------------------------

/**
 * Transforme un chemin relatif en chemin absolu pour images et liens
 * (fonction obsolète)
 */ 
function PathRelativeAbsolute($chaine) {
	return $chaine;
}

// --------------------------------------------------------------------

/**
 * Transforme un chemin absolu en chemin relatif pour images et liens
 */
function PathAbsoluteRelative($chaine)
{
	global $site;

	$str = $chaine;
	
	$in = array(
				'\\',
				'<p>&nbsp;</p>',
				'<br type="_moz" />',
				'<u>',
				'</u>',
				'style="TEXT-DECORATION: underline"',
				'="'.$site[3]
	);
	$out = array(
				'&#92;',
				'<br />',
				'',
				'<span style="text-decoration:underline;">',
				'</span>',
				'style="text-decoration: underline;"',
				'="'
	);

	$str = str_replace($in, $out, $str);
	$str = preg_replace("` src=\"(?:\.\.\/)+`", ' src="', $str);
	$str = preg_replace('`(<br />|&#160;)$`', '', $str);
	
	return $str;
}

// --------------------------------------------------------------------

/**
 * Permet de conserver l'affichage de quelques entités HTML dans le textarea du minieditor
 * 
 * @param $chaine string contient la chaine à traiter
 * @return string chaine traitée
 */
function ReplaceHTMLEntities($chaine)
{
	$str = $chaine;
    
	$in = array(
		'&amp;',
		'&',
		'&amp;amp;lt;',
		'&amp;amp;gt;',
		'&amp;amp;nbsp;',
		'&amp;amp;#'
	);

	$out = array(
		'&',
		'&amp;amp;',
		'&amp;lt;',
		'&amp;gt;',
		'&amp;nbsp;',
		'&amp;#'
	);

	return empty($str)? $str : str_replace($in, $out, $str);
}

// --------------------------------------------------------------------
