<?php
/*******************************************************************************
 *   Functions for editors
 *******************************************************************************
 *   GuppY PHP Script - version 5.0
 *   CeCILL Copyright (C) 2004-2014 by Laurent Duveau
 *   Initiated by Laurent Duveau and Nicolas Alves
 *   Web site = http://www.freeguppy.org/
 *   e-mail   = guppy@freeguppy.org
 *   V5 developed by Lud Bienaimé
 *      with the participation of Jean-Michel Misrachi and the GuppY Team
 *******************************************************************************
 *   Latest Changes :
 * v5.02.09 (June 06, 2019)      : correction of the editor icon bars
 ******************************************************************************/

if (stristr($_SERVER["SCRIPT_NAME"], "editors_functions.php")) {
	header("location:../index.php");
	die();
}

/**
 * Affiche l'éditeur dans la partie web 
 * 
 * @param string  $name    Nom de l'éditeur
 * @param string  $width   Largeur de l'éditeur (voir fichier de condif)
 * @param string  $height  Hauteur de l'éditeur
 * @param string  $content Contenu de l'éditeur
 * @param array   $params  Paramètres optionnels
 * @return string
 */
function display_editor($name, $width, $height, $value, $params = array()) {
	global $site, $lng;
    
    $width = TYP_SCREEN == 'WEB' ? $width : '99%';    
    settype($params, 'array');
    if (is_file(CHEMIN.'inc/ckeditor/ckeditor.php')) {
        require_once CHEMIN.'inc/ckeditor/ckeditor.php';
        $path        = 'inc/ckeditor/';
        $site[37]    = empty($site[37]) ? 'moonocolor_v1.1' : $site[37];
        $toolbarName = empty($params['toolbarName']) ? 'Guppy_out_min' : $params['toolbarName'];
        $smileyBar   = empty($params['smileyBar']) ? '' : $params['smileyBar'];

        $oCKeditor                         = new CKeditor() ;
        $oCKeditor->basePath               = $site[3].$path;
        $oCKeditor->config['width']        = $width;
        $oCKeditor->config['height']       = $height;
        $oCKeditor->config['baseHref']     = $site[3];
        $oCKeditor->config['customConfig'] = $site[3].'inc/ckeditor_config/guppy_ckconfig.js';
        $oCKeditor->config['contentsCss']  = [ $site[3].'inc/ckeditor_config/guppy_contents.css', $site[3].'inc/ckeditor_config/guppy_contents_plus.css' ];
        $oCKeditor->config['language']     = is_file(CHEMIN.'inc/ckeditor/lang/'.$lng.'.js') ? $lng : 'en';	
        $oCKeditor->config['toolbar']      = $toolbarName;
        $oCKeditor->config['smiley_path']  = 'inc/ckeditor/plugins/smiley/images/';
        $oCKeditor->config['skin']         = $site[37].', '.$site[3].'inc/ckeditor_config/skins/'.$site[37].'/';
        
        echo '<div class="textCenter">'.$oCKeditor->editor($name, $value).'</div>';
        if ($smileyBar == '') echo get_toolbar_guppy_smileys($name);    
    }
    else
        return false;
}

// --------------------------------------------------------------------


/**
 * Défini le chemin du répertoire contenant les smileys de guppy
 */
define('PATH_GUPPYSMILEY', 'inc/img/smileys/');	

// --------------------------------------------------------------------

/**
 * Retourne la barre de smileys de guppy pour être intégrer dans l'éditeur
 * 
 * @param string Nom de l'éditeur
 * @return string
 */
function get_toolbar_guppy_smileys($name)
{
	$smileyGuppy = array('cool', 'wink', 'biggrin', 'smile', 'frown', 'eek', 'mad', 'confused', 'rolleyes', 'tongue', 'cry');
	
    $html = '<div class="guppy_smileys" style="text-align:center; margin-top:10px;">';
    
	for ($i = 0; $i < count($smileyGuppy); $i++) {
		$smileyPath = CHEMIN.PATH_GUPPYSMILEY.$smileyGuppy[$i].'.gif';
		if (is_file($smileyPath)) { 
			$imgSize = getimagesize($smileyPath);
			$html .= '<img class="icon" style="cursor:pointer;" src="'.$smileyPath.'" '.$imgSize[3].' alt="'.$smileyGuppy[$i].'" title="'.$smileyGuppy[$i].'" onclick="insert_smiley_in_editor(\''.$name.'\', \''.PATH_GUPPYSMILEY.$smileyGuppy[$i].'.gif\', \''.$smileyGuppy[$i].'\', \''.$imgSize[0].'\', \''.$imgSize[1].'\');" onmouseover="this.className=\'icon_hover\'" onmouseout="this.className=\'icon_out\'" />'."\n";
		}
	}
    
    $html .= '</div>';
    
	return $html;
}

// --------------------------------------------------------------------

/**
 * Insère les fonctions javascripts nécessaires pour les éditeurs
 */ 
$headinc .= '<script src="'.CHEMIN.'inc/ckeditor_config/editors_scripts.js"></script>';

?>