<?php
/*******************************************************************************
 *   Security
 *******************************************************************************
 *   GuppY PHP Script - version 5.0
 *   CeCILL Copyright (C) 2004-2013 by Laurent Duveau
 *   Initiated by Laurent Duveau and Nicolas Alves
 *   Web site = http://www.freeguppy.org/
 *   e-mail   = guppy@freeguppy.org
 *   V5 developed by Lud Bienaimé
 *      with the participation of Jean-Michel Misrachi and the GuppY Team
 *******************************************************************************
 *   Latest Changes :
 * v5.01.03 (June 07, 2016)      : replace css properties by class rules
 *                               : improvement of IP address reading
 ******************************************************************************/

define('SECURITY_REP',  CHEMIN.DATAREP.'security/');
define('BAN_REP',       SECURITY_REP.  'bannis/');
define('BLA_REP',       SECURITY_REP.  'blacklist/');
define('BAN_CFG',       SECURITY_REP.  'ban_cfg.ini');
define('BLA_CFG',       SECURITY_REP.  'bla_cfg.ini');
define('BAN_DEF',       SECURITY_REP.  'ban_def.ini');
define('BLA_DEF',       SECURITY_REP.  'bla_def.ini');

$sec_retention = array(
    0  => (isset($web) ? $web[506] : $admin[1739]),
    4  => '4'.(isset($web) ? $web[507] : $admin[1157]),
    8  => '8'.(isset($web) ? $web[507] : $admin[1157]),
    12 => '12'.(isset($web) ? $web[507] : $admin[1157]),
    24 => '24'.(isset($web) ? $web[507] : $admin[1157]),
    52 => '52'.(isset($web) ? $web[507] : $admin[1157]),
);
$sec_active = array(
    ''   => isset($web) ? $web[508] : $admin[1737],
    'on' => isset($web) ? $web[509] : $admin[1738],
);

function ReadSecurityConfig($file) {
    if (is_file($file)) {
        return parse_ini_file($file);
    } else {
        $cfg = array(
            'nextid' => 1,
            'status' => '',
            'record' => '',
            'retention' => '0'
            );
        WriteSecurityConfig($file, $cfg);
        return $cfg;
    }
}

function WriteSecurityConfig($file, $datas) {
    $out = '';
    foreach ($datas as $key => $value) {
        $out .= $key.'="'.addslashes(trim($value))."\"\n";
    }
    file_put_contents($file, $out);
}

function ReadSecurityDatas($file) {
    if (is_file($file)) {
        return parse_ini_file($file, TRUE);
    } else {
        return array();
    }
}

function WriteSecurityDatas($file, $sections) {
    $out = '';
    foreach ($sections as $section => $datas) {
        $out .= '['.$section.']'."\n";
        foreach ($datas as $key => $value) {
            $out .= $key.'="'.trim($value)."\"\n";
        }
        $out .= "\n";
    }
    file_put_contents($file, $out);
}

function CutField($field, $max = 15, $more = '...') {
	global $charset;
    $len = strlen($field);
    if ($len > $max) {
        return '<acronym title="'.htmlentities($field, ENT_COMPAT, $charset).'" class="cursorHelp">'.substr($field, 0, $max).$more.'</acronym>';
    } else {
        return $field;
    }
}

function SelectSecurity($name, $value, $options) {
    $out = "\n".'<select name="'.$name.'">'."\n";
    foreach ($options as $key=>$option) {
        $out .= '<option value="'.$key.'"'.Selected($key == $value).'>'.$option.'</option>'."\n";
    }
    $out .= '</select>'."\n";
    return $out;
}

function ExecuteBannishment() {
    global $userprefs, $log1, $site, $charset, $web;
	$this_url = 'http://'.$_SERVER['HTTP_HOST'].dirname($_SERVER['PHP_SELF']);
    $cfg = ReadSecurityConfig(BAN_CFG);
    date_default_timezone_set('UTC');
    $typ = isset($_REQUEST['typ']) ? $_REQUEST['typ'] : '';
    $add = isset($_REQUEST['add']) ? $_REQUEST['add'] : '';
    $datas = array(
        date('Ymd His'),
        '-',
        getIPadress($_SERVER[$site[6] == 'on' ? 'HTTP_X_FORWARDED_FOR' : 'REMOTE_ADDR']),
        sprintf('typ=%s add=%s', $typ, $add),
        $userprefs[1],
        $userprefs[2],
        $userprefs[9],
        @gethostbyaddr(getIPadress($_SERVER[$site[6] == 'on' ? 'HTTP_X_FORWARDED_FOR' : 'REMOTE_ADDR'])),
        $_SERVER['HTTP_USER_AGENT'],
        isset($_SERVER['HTTP_REFERER']) ? $_SERVER['HTTP_REFERER'] : '',
        $log1
    );
    date_default_timezone_set($site['TZ']);
    $rejet = FALSE;
    if ('on' == $cfg['status']) {
        $defs = ReadSecurityDatas(BAN_DEF);
        foreach ($defs as $id => $def) {
            if (empty($def['status'])) continue;
            $url = $def['url'];
            $msg = $def['msg'];
            $motif = 'BAN('.$id;
            if (!empty($def['ip'])) {
                $rejet = $rejet || (getIPadress($_SERVER[$site[6] == 'on' ? 'HTTP_X_FORWARDED_FOR' : 'REMOTE_ADDR']) == $def['ip']);
                if ($rejet) {
                    $motif .= ',ip)';
                    break;
                }
            }
            if (!empty($def['agent'])) {
                $rejet = $rejet || (mb_substr_count(mb_strtolower($_SERVER['HTTP_USER_AGENT'], $charset), mb_strtolower($def['agent'], $charset), $charset) != 0);
                if ($rejet) {
                    $motif .= ',agent)';
                    break;
                }
            }
            if (!empty($def['host'])) {
                $host = mb_strtolower(@gethostbyaddr(getIPadress($_SERVER[$site[6] == 'on' ? 'HTTP_X_FORWARDED_FOR' : 'REMOTE_ADDR'])), $charset);
                $values = explode(" ", $def['host']);
                $rejet1 = TRUE;
                foreach($values as $value1) {
                    $rejet1 = $rejet1 && (substr_count($host, $value1) != 0);
                    if (!$rejet1) {
                        break;
                    }
                }
                $rejet = $rejet || $rejet1;
                if ($rejet) {
                    $motif .= ',host)';
                    break;
                }
            }
        }
    }
    $datas[1] = $rejet ? $motif : '';
    if ('on' == $cfg['record'] && $datas[1] != '') {
        $file = BAN_REP.date('Y-W').DBEXT;
        if (FileDBExist($file)) {
            AppendDbFields($file, $datas);
        } else {
            WriteDbFields($file, array($datas));
            PurgeSecurityLog(BAN_REP, $cfg['retention']);
        }
    }
    if ($rejet) {
        if (!empty($msg)) {
            $eSub = stripslashes($site[($lang[0] == $lng ? 0 : 11)]).' '.$web[451].$msg;
            $eMsg = stripslashes($site[($lang[0] == $lng ? 0 : 11)]).'<hr /><strong>'.$msg.'</strong><hr />'.$web[452].$web[478].'<br />';
            $eMsg .= $web[453].$datas[0].'.<br />';
            $eMsg .= $web[454].$datas[1].'.<br />';
            $eMsg .= $web[455].$datas[2].'.<br />';
            $eMsg .= $web[456].$datas[3].'.<br />';
            $eMsg .= $web[457].$datas[4].'.<br />';
            $eMsg .= $web[458].$datas[5].'.<br />';
            $eMsg .= $web[459].$datas[6].'.<br />';
            $eMsg .= $web[460].$datas[7].'.<br />';
            $eMsg .= $web[461].$datas[8].'.<br />';
            $eMsg .= $web[462].$datas[9].'.<br />';
            $eMsg .= $web[463].$datas[10].'.<br />';
            $eMsg .= '<hr />';
            eMailHtmlTo($eSub, $eMsg, '');
        }
        switch($url) {
		case '' :
			header('location:'.$this_url);
        case '401' :
            header('HTTP/1.0 401 Unauthorized');
            exit();
        case '403' :
            header('HTTP/1.0 403 Forbidden');
            exit();
        case '404' :
            header('HTTP/1.0 404 Not Found');
            exit();
        case '410' :
            header('HTTP/1.0 410 Gone');
            exit();
        default :
            header('location:'.$url);
            exit();
        }
    }
}

function ExecuteBlackList() {
    global $pseudo, $pemail, $purl, $ptit, $ptxt, $log1, $site, $charset, $web;
	$this_url = 'http://'.$_SERVER['HTTP_HOST'].dirname($_SERVER['PHP_SELF']);
    $cfg = ReadSecurityConfig(BLA_CFG);
    date_default_timezone_set('UTC');
    $datas = array(
        date('Ymd His'),
        '-',
        getIPadress($_SERVER[$site[6] == 'on' ? 'HTTP_X_FORWARDED_FOR' : 'REMOTE_ADDR']),
        sprintf('typ=%s add=%s', $_REQUEST['typ'], $_REQUEST['add']),
        $pseudo,
        $pemail,
        $purl,
        @gethostbyaddr(getIPadress($_SERVER[$site[6] == 'on' ? 'HTTP_X_FORWARDED_FOR' : 'REMOTE_ADDR'])),
        $_SERVER['HTTP_USER_AGENT'],
        $_SERVER['HTTP_REFERER'],
        $log1
    );
    date_default_timezone_set($site['TZ']);
    $rejet = FALSE;
    if ('on' == $cfg['status']) {
        $defs = ReadSecurityDatas(BLA_DEF);
        foreach ($defs as $id => $def) {
            if (empty($def['status'])) continue;
            $url = $def['url'];
            $msg = $def['msg'];
            $motif = 'BLA('.$id;
            if (!empty($def['ip'])) {
                $rejet = $_SERVER[$site[6] == 'on' ? 'HTTP_X_FORWARDED_FOR' : 'REMOTE_ADDR'] == stristr($_SERVER[$site[6] == 'on' ? 'HTTP_X_FORWARDED_FOR' : 'REMOTE_ADDR'], $def['ip']);
                if ($rejet) {
                    $motif .= ',ip)';
                    break;
                }
            }
            if (!$rejet && !empty($def['pseudo'])) {
                $rejet = FALSE !== stristr(mb_strtolower($pseudo, $charset), mb_strtolower($def['pseudo'], $charset));
                if ($rejet) {
                    $motif .= ',pseudo)';
                    break;
                }
            }
            if (!$rejet && !empty($def['email'])) {
                $rejet = FALSE !== stristr(mb_strtolower($pemail, $charset), mb_strtolower($def['email'], $charset));
                if ($rejet) {
                    $motif .= ',email)';
                    break;
                }
            }
            if (!$rejet && !empty($def['web'])) {
                $rejet = FALSE !== stristr(mb_strtolower($purl, $charset), mb_strtolower($def['web'], $charset));
                if ($rejet) {
                    $motif .= ',web)';
                    break;
                }
            }
            if (!$rejet && !empty($def['agent'])) {
                $rejet = FALSE !== stristr(mb_strtolower($_SERVER['HTTP_USER_AGENT'], $charset), mb_strtolower($def['agent'], $charset));
                if ($rejet) {
                    $motif .= ',agent)';
                    break;
                }
            }
            if (!$rejet && !empty($def['host'])) {
                $host = mb_strtolower(@gethostbyaddr(getIPadress($_SERVER[$site[6] == 'on' ? 'HTTP_X_FORWARDED_FOR' : 'REMOTE_ADDR'])), $charset);
                $values = explode(" ", $def['host']);
                $rejet1 = TRUE;
                foreach($values as $value1) {
                    $rejet1 = FALSE === stristr($host, $value1);
                    if (!$rejet1) {
                        break;
                    }
                }
                $rejet = $rejet || !$rejet1;
                if ($rejet) {
                    $motif .= ',host)';
                    break;
                }
            }
            if (!$rejet && !empty($def['mots'])) {
                $ptext = $ptit.'|'.$ptxt;
                $values = explode(" ", $def['mots']);
                $rejet1 = TRUE;
                foreach($values as $value1) {
                    $rejet1 = FALSE === stristr($ptext, $value1);
                    if (!$rejet1) {
                        break;
                    }
                }
                $rejet = $rejet || !$rejet1;
                if ($rejet) {
                    $motif .= ',mot='.$value1.')';
                    break;
                }
            }
        }
    }
    $datas[1] = $rejet ? $motif : '';
    if ('on' == $cfg['record'] && $datas[1] != '') {
        $file = BLA_REP.date('Y-W').DBEXT;
        if (FileDBExist($file)) {
            AppendDbFields($file, $datas);
        } else {
            WriteDbFields($file, array($datas));
            PurgeSecurityLog(BLA_REP, $cfg['retention']);
        }
    }
    if ($rejet) {
        if (!empty($msg)) {
            $eSub = stripslashes($site[($lang[0] == $lng ? 0 : 11)]).' '.$web[451].$msg;
            $eMsg = stripslashes($site[($lang[0] == $lng ? 0 : 11)]).'<hr /><strong>'.$msg.'</strong><hr />'.$web[452].$web[479].'<br />';
            $eMsg .= $web[453].$datas[0].'.<br />';
            $eMsg .= $web[454].$datas[1].'.<br />';
            $eMsg .= $web[455].$datas[2].'.<br />';
            $eMsg .= $web[456].$datas[3].'.<br />';
            $eMsg .= $web[457].$datas[4].'.<br />';
            $eMsg .= $web[458].$datas[5].'.<br />';
            $eMsg .= $web[459].$datas[6].'.<br />';
            $eMsg .= $web[460].$datas[7].'.<br />';
            $eMsg .= $web[461].$datas[8].'.<br />';
            $eMsg .= $web[462].$datas[9].'.<br />';
            $eMsg .= $web[463].$datas[10].'.<br />';
            $eMsg .= '<hr />';
            eMailHtmlTo($eSub, $eMsg, '');
        }
        switch($url) {
		case '' :
			header('location:'.$this_url);
        case '401' : 
            header('HTTP/1.0 401 Unauthorized');
            exit();
        case '403' :
            header('HTTP/1.0 403 Forbidden');
            exit();
        case '404' :
            header('HTTP/1.0 404 Not Found');
            exit();
        case '410' :
            header('HTTP/1.0 410 Gone');
            exit();
        default :
            header('location:'.$url);
            exit();
        }
    }
}

function PurgeSecurityLog($dir, $retention) {
    if (0 == $retention) return;
    $lastyear = date('Y');
    $lastweek = date('W') - $retention;
    if ($lastweek < 1) {
        $lastyear--;
        $lastweek += 52;
    }
    $lastfile = sprintf('%4d-%02d.dtb', $lastyear, $lastweek);
    $files = ExploreFile($dir);
    foreach ($files as $file) {
        if ($file < $lastfile) {
            DestroyDBFile($dir.$file);
        }
    }
}

?>
